@@ -16,9 +16,6 @@ def list_files(startpath):
 				continue
 			elif env_name in root:
 				continue
-  			#REMOVE LATER
-			if "api" in root:
-				continue
 		for f in files:
 			if f.endswith(".py") :
 				file_list.append(f"{root}/{f}")
@@ -34,7 +31,10 @@ def update_requirements(janetrecord):
 		temp_file.write(frozen_packages)
 
 	with open("requirements.txt", "w") as requirements_file:
-		requirements_file.writelines(line for line in open("_temp_janet_file.txt") if line not in janetrecord.janet_requirements)
+		for line in open("_temp_janet_file.txt"):
+			line_splitted = line.split("==")[0].lower()
+			if line_splitted not in janetrecord.janet_requirements:
+				requirements_file.writelines(line)
 
 	os.remove("_temp_janet_file.txt")
 
